from __future__ import annotations

from typing import Any

LLM_REASONING_ARG_NAME = "llm_reasoning__"


def remove_llm_reasoning_arg(wrapped_tool_args: dict[str, Any]) -> dict[str, Any]:
    """Return tool args without the synthetic LLM reasoning argument."""
    return {k: v for k, v in wrapped_tool_args.items() if k != LLM_REASONING_ARG_NAME}
